==> zio-aws-lightsail_2.13-5.17.104.4-sources.jar: zio/aws/lightsail/model/Bundle.scala <==
package zio.aws.lightsail.model
import zio.aws.lightsail.model.primitives.{NonEmptyString, Integer}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class Bundle(
    price: Option[Float] = None,
    cpuCount: Option[Integer] = None,
    diskSizeInGb: Option[Integer] = None,
    bundleId: Option[NonEmptyString] = None,
    instanceType: Option[String] = None,
    isActive: Option[Boolean] = None,
    name: Option[String] = None,
    power: Option[Integer] = None,
    ramSizeInGb: Option[Float] = None,
    transferPerMonthInGb: Option[Integer] = None,
    supportedPlatforms: Option[
      Iterable[zio.aws.lightsail.model.InstancePlatform]
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lightsail.model.Bundle = {
    import Bundle.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lightsail.model.Bundle
      .builder()
      .optionallyWith(price.map(value => value: java.lang.Float))(_.price)
      .optionallyWith(
        cpuCount.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.cpuCount)
      .optionallyWith(
        diskSizeInGb.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.diskSizeInGb)
      .optionallyWith(
        bundleId.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.bundleId)
      .optionallyWith(instanceType.map(value => value: java.lang.String))(
        _.instanceType
      )
      .optionallyWith(isActive.map(value => value: java.lang.Boolean))(
        _.isActive
      )
      .optionallyWith(name.map(value => value: java.lang.String))(_.name)
      .optionallyWith(
        power.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.power)
      .optionallyWith(ramSizeInGb.map(value => value: java.lang.Float))(
        _.ramSizeInGb
      )
      .optionallyWith(
        transferPerMonthInGb.map(value =>
          Integer.unwrap(value): java.lang.Integer
        )
      )(_.transferPerMonthInGb)
      .optionallyWith(
        supportedPlatforms.map(value =>
          value.map { item =>
            item.unwrap.toString
          }.asJavaCollection
        )
      )(_.supportedPlatformsWithStrings)
      .build()
  }
  def asReadOnly: zio.aws.lightsail.model.Bundle.ReadOnly =
    zio.aws.lightsail.model.Bundle.wrap(buildAwsValue())
}
object Bundle {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.lightsail.model.Bundle] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lightsail.model.Bundle =
      zio.aws.lightsail.model.Bundle(
        price.map(value => value),
        cpuCount.map(value => value),
        diskSizeInGb.map(value => value),
        bundleId.map(value => value),
        instanceType.map(value => value),
        isActive.map(value => value),
        name.map(value => value),
        power.map(value => value),
        ramSizeInGb.map(value => value),
        transferPerMonthInGb.map(value => value),
        supportedPlatforms.map(value => value)
      )
    def price: Option[Float]
    def cpuCount: Option[Integer]
    def diskSizeInGb: Option[Integer]
    def bundleId: Option[NonEmptyString]
    def instanceType: Option[String]
    def isActive: Option[Boolean]
    def name: Option[String]
    def power: Option[Integer]
    def ramSizeInGb: Option[Float]
    def transferPerMonthInGb: Option[Integer]
    def supportedPlatforms
        : Option[List[zio.aws.lightsail.model.InstancePlatform]]
    def getPrice: ZIO[Any, AwsError, Float] =
      AwsError.unwrapOptionField("price", price)
    def getCpuCount: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("cpuCount", cpuCount)
    def getDiskSizeInGb: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("diskSizeInGb", diskSizeInGb)
    def getBundleId: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("bundleId", bundleId)
    def getInstanceType: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("instanceType", instanceType)
    def getIsActive: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("isActive", isActive)
    def getName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("name", name)
    def getPower: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("power", power)
    def getRamSizeInGb: ZIO[Any, AwsError, Float] =
      AwsError.unwrapOptionField("ramSizeInGb", ramSizeInGb)
    def getTransferPerMonthInGb: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("transferPerMonthInGb", transferPerMonthInGb)
    def getSupportedPlatforms
        : ZIO[Any, AwsError, List[zio.aws.lightsail.model.InstancePlatform]] =
      AwsError.unwrapOptionField("supportedPlatforms", supportedPlatforms)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lightsail.model.Bundle
  ) extends zio.aws.lightsail.model.Bundle.ReadOnly {
    override val price: Option[Float] =
      scala.Option(impl.price()).map(value => value: Float)
    override val cpuCount: Option[Integer] = scala
      .Option(impl.cpuCount())
      .map(value => zio.aws.lightsail.model.primitives.Integer(value))
    override val diskSizeInGb: Option[Integer] = scala
      .Option(impl.diskSizeInGb())
      .map(value => zio.aws.lightsail.model.primitives.Integer(value))
    override val bundleId: Option[NonEmptyString] = scala
      .Option(impl.bundleId())
      .map(value => zio.aws.lightsail.model.primitives.NonEmptyString(value))
    override val instanceType: Option[String] =
      scala.Option(impl.instanceType()).map(value => value: String)
    override val isActive: Option[Boolean] =
      scala.Option(impl.isActive()).map(value => value: Boolean)
    override val name: Option[String] =
      scala.Option(impl.name()).map(value => value: String)
    override val power: Option[Integer] = scala
      .Option(impl.power())
      .map(value => zio.aws.lightsail.model.primitives.Integer(value))
    override val ramSizeInGb: Option[Float] =
      scala.Option(impl.ramSizeInGb()).map(value => value: Float)
    override val transferPerMonthInGb: Option[Integer] = scala
      .Option(impl.transferPerMonthInGb())
      .map(value => zio.aws.lightsail.model.primitives.Integer(value))
    override val supportedPlatforms
        : Option[List[zio.aws.lightsail.model.InstancePlatform]] = scala
      .Option(impl.supportedPlatforms())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.lightsail.model.InstancePlatform.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.lightsail.model.Bundle
  ): zio.aws.lightsail.model.Bundle.ReadOnly = new Wrapper(impl)
}

==> zio-aws-lightsail_3-5.17.150.1-sources.jar: zio/aws/lightsail/model/Bundle.scala <==
package zio.aws.lightsail.model
import zio.aws.lightsail.model.primitives.{NonEmptyString, Integer}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class Bundle(
    price: Option[Float] = None,
    cpuCount: Option[Integer] = None,
    diskSizeInGb: Option[Integer] = None,
    bundleId: Option[NonEmptyString] = None,
    instanceType: Option[String] = None,
    isActive: Option[Boolean] = None,
    name: Option[String] = None,
    power: Option[Integer] = None,
    ramSizeInGb: Option[Float] = None,
    transferPerMonthInGb: Option[Integer] = None,
    supportedPlatforms: Option[
      Iterable[zio.aws.lightsail.model.InstancePlatform]
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lightsail.model.Bundle = {
    import Bundle.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lightsail.model.Bundle
      .builder()
      .optionallyWith(price.map(value => value: java.lang.Float))(_.price)
      .optionallyWith(cpuCount.map(value => value: java.lang.Integer))(
        _.cpuCount
      )
      .optionallyWith(diskSizeInGb.map(value => value: java.lang.Integer))(
        _.diskSizeInGb
      )
      .optionallyWith(
        bundleId.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.bundleId)
      .optionallyWith(instanceType.map(value => value: java.lang.String))(
        _.instanceType
      )
      .optionallyWith(isActive.map(value => value: java.lang.Boolean))(
        _.isActive
      )
      .optionallyWith(name.map(value => value: java.lang.String))(_.name)
      .optionallyWith(power.map(value => value: java.lang.Integer))(_.power)
      .optionallyWith(ramSizeInGb.map(value => value: java.lang.Float))(
        _.ramSizeInGb
      )
      .optionallyWith(
        transferPerMonthInGb.map(value => value: java.lang.Integer)
      )(_.transferPerMonthInGb)
      .optionallyWith(
        supportedPlatforms.map(value =>
          value.map { item =>
            item.unwrap.toString
          }.asJavaCollection
        )
      )(_.supportedPlatformsWithStrings)
      .build()
  }
  def asReadOnly: zio.aws.lightsail.model.Bundle.ReadOnly =
    zio.aws.lightsail.model.Bundle.wrap(buildAwsValue())
}
object Bundle {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.lightsail.model.Bundle] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lightsail.model.Bundle =
      zio.aws.lightsail.model.Bundle(
        price.map(value => value),
        cpuCount.map(value => value),
        diskSizeInGb.map(value => value),
        bundleId.map(value => value),
        instanceType.map(value => value),
        isActive.map(value => value),
        name.map(value => value),
        power.map(value => value),
        ramSizeInGb.map(value => value),
        transferPerMonthInGb.map(value => value),
        supportedPlatforms.map(value => value)
      )
    def price: Option[Float]
    def cpuCount: Option[Integer]
    def diskSizeInGb: Option[Integer]
    def bundleId: Option[NonEmptyString]
    def instanceType: Option[String]
    def isActive: Option[Boolean]
    def name: Option[String]
    def power: Option[Integer]
    def ramSizeInGb: Option[Float]
    def transferPerMonthInGb: Option[Integer]
    def supportedPlatforms
        : Option[List[zio.aws.lightsail.model.InstancePlatform]]
    def getPrice: ZIO[Any, AwsError, Float] =
      AwsError.unwrapOptionField("price", price)
    def getCpuCount: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("cpuCount", cpuCount)
    def getDiskSizeInGb: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("diskSizeInGb", diskSizeInGb)
    def getBundleId: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("bundleId", bundleId)
    def getInstanceType: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("instanceType", instanceType)
    def getIsActive: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("isActive", isActive)
    def getName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("name", name)
    def getPower: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("power", power)
    def getRamSizeInGb: ZIO[Any, AwsError, Float] =
      AwsError.unwrapOptionField("ramSizeInGb", ramSizeInGb)
    def getTransferPerMonthInGb: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("transferPerMonthInGb", transferPerMonthInGb)
    def getSupportedPlatforms
        : ZIO[Any, AwsError, List[zio.aws.lightsail.model.InstancePlatform]] =
      AwsError.unwrapOptionField("supportedPlatforms", supportedPlatforms)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lightsail.model.Bundle
  ) extends zio.aws.lightsail.model.Bundle.ReadOnly {
    override val price: Option[Float] =
      scala.Option(impl.price()).map(value => value: Float)
    override val cpuCount: Option[Integer] =
      scala.Option(impl.cpuCount()).map(value => value: Integer)
    override val diskSizeInGb: Option[Integer] =
      scala.Option(impl.diskSizeInGb()).map(value => value: Integer)
    override val bundleId: Option[NonEmptyString] = scala
      .Option(impl.bundleId())
      .map(value => zio.aws.lightsail.model.primitives.NonEmptyString(value))
    override val instanceType: Option[String] =
      scala.Option(impl.instanceType()).map(value => value: String)
    override val isActive: Option[Boolean] =
      scala.Option(impl.isActive()).map(value => value: Boolean)
    override val name: Option[String] =
      scala.Option(impl.name()).map(value => value: String)
    override val power: Option[Integer] =
      scala.Option(impl.power()).map(value => value: Integer)
    override val ramSizeInGb: Option[Float] =
      scala.Option(impl.ramSizeInGb()).map(value => value: Float)
    override val transferPerMonthInGb: Option[Integer] =
      scala.Option(impl.transferPerMonthInGb()).map(value => value: Integer)
    override val supportedPlatforms
        : Option[List[zio.aws.lightsail.model.InstancePlatform]] = scala
      .Option(impl.supportedPlatforms())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.lightsail.model.InstancePlatform.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.lightsail.model.Bundle
  ): zio.aws.lightsail.model.Bundle.ReadOnly = new Wrapper(impl)
}
